pub struct Location {
pub start: usize,
pub end: usize,
}Expand description
Represents a location in the source Dataweave expression, typically used for error reporting.
The start and end fields represent the character offsets in the source string.
Fields
start: usizeThe starting character offset of the location (inclusive).
end: usizeThe ending character offset of the location (exclusive).
Implementations